// main colors
$body-bg: #fff !default;
$body-color: #222 !default;
$text-muted: lighten($body-color, 30%) !default;

// border colors
$border-color: lighten($body-color, 30%) !default;
$table-border-color: $border-color !default;
$border-width: 1px !default;
$border-radius: 4px !default;
