[{"locale":"es"},{"key":"00F8","mappings":{"default":{"default":"o barrada"}},"category":"Ll"},{"key":"0111","mappings":{"default":{"default":"d con barra"}},"category":"Ll"},{"key":"0127","mappings":{"default":{"default":"h con guión"}},"category":"Ll"},{"key":"0142","mappings":{"default":{"default":"l con guión"}},"category":"Ll"},{"key":"0167","mappings":{"default":{"default":"t con guión"}},"category":"Ll"},{"key":"019B","mappings":{"default":{"default":"lambda tachada"}},"category":"Ll"},{"key":"1E9B","mappings":{"default":{"default":"s larga con punto arriba"}},"category":"Ll"},{"key":"0138","mappings":{"default":{"default":"kra"}},"category":"Ll"},{"key":"0192","mappings":{"default":{"default":"f con gancho"}},"category":"Ll"},{"key":"019A","mappings":{"default":{"default":"l con barra"}},"category":"Ll"},{"key":"025B","mappings":{"default":{"default":"e abierta"}},"category":"Ll"},{"key":"0149","mappings":{"default":{"default":"n precedida por apóstrofe"}},"category":"Ll"},{"key":"014B","mappings":{"default":{"default":"eng"}},"category":"Ll"}]
