/*
 *  /MathJax/localization/sv/HelpDialog.js
 *
 *  Copyright (c) 2009-2018 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.Localization.addTranslation("sv","HelpDialog",{version:"2.7.6",isLoaded:true,strings:{Help:"MathJax-hj\u00E4lp",MathJax:"*MathJax* \u00E4r ett JavaScript-bibliotek som till\u00E5ter f\u00F6rfattare att inkludera matematik p\u00E5 sina webbsidor. Som l\u00E4sare beh\u00F6ver du inte g\u00F6ra n\u00E5got f\u00F6r att f\u00E5 det att h\u00E4nda.",Browsers:"*Webbl\u00E4sare*: MathJax fungerar med alla moderna webbl\u00E4sare inklusive IE6+, Firefox 3+, Chrome 0.2+, Safari 2+, Opera 9.6+ och de flesta mobila webbl\u00E4sare.",Menu:"*Matematik-menyn*: MathJax l\u00E4gger till en kontextuell meny till ekvationer. H\u00F6gerklicka eller Ctrl-klicka p\u00E5 n\u00E5gon matematik att komma \u00E5t menyn.",ShowMath:"*Visa matematik som* g\u00F6r att du kan visa formelns k\u00E4llkod f\u00F6r att klipp \u0026 klistra in (som MathML eller i dess ursprungliga format).",Settings:"*Inst\u00E4llninga * ger dig kontroll \u00F6ver funktionerna i MathJax, s\u00E5 som storleken p\u00E5 matematiken och den mekanism som anv\u00E4nds f\u00F6r att visa ekvationer.",Language:"*Spr\u00E5k* l\u00E5ter dig v\u00E4lja spr\u00E5ket som MathJax ska anv\u00E4nda f\u00F6r sina menyer och varningsmeddelanden.",Zoom:"*Matematik zoom*: Om du har sv\u00E5rt att l\u00E4sa en ekvation, kan MathJax f\u00F6rstora den f\u00F6r att hj\u00E4lpa dig se den b\u00E4ttre.",Accessibilty:"*Tillg\u00E4nglighet*: MathJax fungerar automatiskt med sk\u00E4rml\u00E4sare f\u00F6r att g\u00F6ra matematik tillg\u00E4nglig f\u00F6r synskadade.",Fonts:"*Typsnitt*: MathJax kommer att anv\u00E4nda vissa matematiska teckensnitt om de \u00E4r installerade p\u00E5 din dator; annars anv\u00E4nder den webb-baserade teckensnitt. \u00C4ven om det inte kr\u00E4vs, kommer lokalt installerade teckensnitt att p\u00E5skynda typs\u00E4ttningen. Vi f\u00F6resl\u00E5r installation av [STIX-typsnitt](%1).",CloseDialog:"St\u00E4ng hj\u00E4lpdialogen"}});MathJax.Ajax.loadComplete("[MathJax]/localization/sv/HelpDialog.js");
